#!/usr/bin/perl
#
#  Logplay2: Logplay Version 2.0 (Amadeus)
#      Distributed under the GPL
#
# lp2config.pl v2.0
#  lp2config.pl - the configuration tool for logplay

&setup; 	# (set up base things)


foreach (@ARGV)
{
  &usage if (m/version/);
  &usage if (m/-v/);
  &usage($usage, $desc) if (m/help/);
  &usage($usage, $desc) if (m/-h/);
}

sub setup 
{
  #
  #  This function is pretty obvious. it sets up internal values for finding things.
  # 
  $base_dir = &find_base_dir;
  $debug && print("Base Dir: $base_dir\n");
  $mod_dir = "$base_dir/modules";
  $lib_dir = "$base_dir/lib";
  $etc_dir = "$base_dir/etc";
  $bin_dir = "$base_dir/bin";
  require "$lib_dir/funcs.pl";
  require "$lib_dir/version.pl";
  $progname = $0;
  $progname =~ s+.*/++;
  $progname =~ s/\.pl$//;
  	
  @usage = ("usage", "$progname is not yet written, at all. However, the next version of $x_package",
           "will focus on $progname... Please be patient, It will be done ASAP. =)");
  $usage = join(" ::: ", @usage);
  $desc  = "desc: The Logplay2 Configuration tool. Will eventually configure every aspect of logplay."
}

sub find_base_dir
{
  #
  #  If this function does not work, either logplay is not installed or is
  # installed poorly, or by someone who has not read the installation 
  # instructions, or something. This really SHOULD find the logplay 
  # installation. (Though it may not work if someone has two logplay 
  # installations..)
  #
  #  It will look for the installation directory in /usr/logplay, 
  # /usr/logplay2, /usr/local/logplay, /usr/local/logplay2, /usr/share/logplay,
  # /usr/share/logplay2, /opt/logplay, /opt/logplay2, ~/logplay, ~/logplay2,
  # ~/.logplay/logplay, and ~/.logplay/logplay2.
  #
  # And THEN if it's in none of those places, it then looks for a 
  #  'LOGPLAYPATH = /path/to/logplay' line in the following files:
  #  (skipping the rest if it finds it)
  #  - /etc/logplay.conf, /etc/.logplayconf, /etc/logplay,
  #  - /etc/logplay/logplay.conf, /etc/logplay/.logplayconf, /etc/logplay/logplay,
  #  - /usr/etc/logplay.conf, /usr/etc/.logplayconf, /usr/etc/logplay,
  #  - /usr/local/etc/logplay.conf, /usr/local/etc/.logplayconf, /usr/local/etc/logplay,
  #  - /usr/logplay.conf, /usr/.logplayconf, /usr/logplay,
  #  - /usr/local/logplay.conf, /usr/local/.logplayconf, /usr/local/logplay,
  #  - /usr/share/logplay.conf, /usr/share/.logplayconf, /usr/share/logplay,
  #  - /opt/logplay.conf, /opt/.logplayconf, /opt/logplay,
  #  - ~/logplay.conf, ~/.logplayconf, ~/logplay,
  #  - ~/.logplay/logplay.conf, ~/.logplay/.logplayconf, ~/.logplay/logplay.
  # that 'LOGPLAYPATH' line will contain what will become the $base_dir.
  #
  #  Finally, it tries to find logplay's path by examining $0, and looking for 
  # funcs.pl. if this doesn't work, and everything else failed, it's not my fault.
  # The user, at this point, should RTFM. I've done WAY too much work already 
  # on this one function... ;)
  #
  #  HOWEVER, I am sure that RedHat or Mandrake or SOMEONE will add a 'feature'
  # of a different install directory for basic files or something, and i'll have
  # to modify this. *sigh*.
  # 
  #  Side note: placing it in one of the directories in @bdirlist will improve
  # startup time, as it skips that second chunk of searching. ;)
  
  my @bdirlist = ('/usr', '/usr/local', '/usr/share', '/opt', $ENV{HOME}, "$ENV{HOME}/.logplay");
  my $found = 'notfound';
  
  foreach $attempt (@bdirlist) 
  {
    if ( -x "$attempt/logplay/bin/logplayd" )
    {
      $found = "$attempt/logplay";
    }
    if ( -x "$attempt/logplay2/bin/logplayd" )
    {
      $found = "$attempt/logplay2";
    }
  }
  if ($found eq 'notfound') # ifnofound/1
  {
    foreach $dir ('/etc', '/etc/logplay', '/usr/etc', '/usr/local/etc', @bdirlist) # foreach/dir
    {
      if ($found eq 'notfound') # ifnofound/2 
      # (this stops it from rechecking in this foreach if it gets found)
      {
        foreach $conffile ('logplay.conf', '.logplayconf', 'logplay') # foreach/conffile
        {
          if ( -f "$dir/$conffile" ) # ifdasheff
	  {
            $path = qx(cat /etc/logplay.conf | grep LOGPLAYPATH | sed 's/.*= //g');
            chomp $path;
            $found = $path;
	  } # end ifdasheff
        } # end foreach/conffile
      } # end ifnofound/2
    } # end foreach/dir
  } #end ifnofound/1
  
  if ($found eq 'notfound')  # the final check.
  {
    #
    #  Here we hope that we can find logplay by looking at $0...
    
    my $tmp = my $tmp2= $0;
    
    # 
    #  This turns '/a/stupid/logplay/directory/bin/logplayd'($0) into logplayd,
    # and even '/stupid/dir/bin/badly-named-logplay' to 'badly-named-logplay'
    # and puts that value in $tmp...
    
    $tmp =~ s+.*/++;
    
    
    #
    #  And this turns '/a/stupid/logplay/directory/bin/$tmp' into 
    # '/a/very/stupid/logplay/directory' and places that as $tmp2.
    
    $tmp2 =~ s+bin/$tmp++;
    
    #
    #  Finally, checks for '/a/stupid/logplay/directory/lib/funcs.pl', 
    # (the value of $tmp2) and if it exists, we can use that.
    if ( -f "$tmp2/lib/funcs.pl" )
    {
      $found = $tmp2;
    }
  }

  #
  #  At this point, it's safe to verbally abuse the user for mis-installing.
  # However, i'm nicer than that and we die() with a slightly happier message.
  die "Logplay exited without finding it's base directory. this is not my fault. \n RTFM and try installing it like we tell you to. ;)" if ($found eq 'notfound');
  return($found);
}
