&new_monitor('loadavg');
sub event_get_loadavg
{
  # my $cow = qx(w | head -1); 
  my $cow = qx(uptime); 
  #return($cow);
  &event_parse_loadavg($cow);
}

sub event_parse_loadavg
{
  my $to_parse = shift;
  chomp $to_parse;
  $to_parse =~ s/.*: ([0-9]\.[0-9][0-9]).*/\1/g;
  my $parsed = &parse_loadavg_stage2($to_parse);
  my ($stype, $sound) = &module_loadavg_output($parsed);
  &logplay($stype, $sound) if ($stype ne "NONE");
}
sub module_loadavg_setup
{
  #  This is the Setup for the loadavg config file.
  # The file works as follows: ('> ' is my own marking, not part of the file)
  #  > (Numeric Value Representing Threshhold)
  #  > up ::: (SOUNDTYPE) %%% (SOUNDFILE) ::: Comment
  #  (repeat up line for as many up sounds as you want)
  #  > down ::: (SOUNDTYPE) %%% (SOUNDFILE) ::: Comment
  #  (repeat as well)
  #  (anything that does not start with 'up' or 'down' and is not the first line
  #  will be promptly ignored)
  #
  # What that all means: 
  #  logplay will periodically scan the load average with this module (obviously)
  # and play sounds based on a load thresh-hold. (obviousness meter rising). The
  # For example, if your threshhold is set to .75, a load average of anywhere 
  # between 0.00 and 0.74 will be considered a severity level of 0, then anywhere
  # between 0.75 and 1.49 will be considered a severity level of 1, then anywhere
  # between 1.50 and 2.24 will be considered a severity level of 2, then anywhere
  # between 2.25 and 3.00 will be considered a severity level of 3, and so forth 
  # into the infinite void.
  #
  #  This is where the up and down sounds come in. for each 'up' soundfile in the
  # file, there's a severity level. the 'up' levels start with 1 and go up, and
  # the 'down' levels go up from 0 in our invisible county thing.
  #
  #  So, to really explain. When the load average jumps from 0.00 to 0.78 and 
  # logplay sees it happen, it sends an "up 1" message (meaning the load has gone 
  # 'up' to severity level 1) and the logplay() routine will receive the First 'up'
  # sound listed in the file.
  #
  #  Similarly, if the load average drops from 2.53 down to 1.21, it sends itself
  # a "down 1" message (meaning that the load has gone 'down' to the severity level
  # 1) and the logplay() routine would receive the second 'down' file listed in the 
  # file. 
  #  
  #  The reasoning for the counting skew (as the obviousness meter bursts) is that 
  # we really don't need to know when the load has gone up to level 0, since it 
  # can't come from a negative security level, yet the 'down' can go down to level
  # 0. 
  #
  #  Presto. logplay monitors loads now. whee. ;)
  #
  #  And of course, SOUNDTYPE and SOUNDFILE may be any of the types that the 
  # logplay() routine recognizes (located in $mod_dir/output/), as they are the
  # $stype and $sound variables passed to logplay() in the main file. =)
  # 
  
  
  my $etcfile = "$base_dir/etc/loadavg.conf";
  open(EFILE, "< $etcfile"); # or die("hey. can't open $etcfile.");
  $mod_lavg_thold = <EFILE>;
  my $upcount = my $downcount = 0;
  $upcount++;
  while (<EFILE>)
  {
    if (/^up/)
    {
      ($tmp, $loadavg_up[$upcount]) = split(" ::: ", $_);
      $upcount++;
    } 
    elsif (/^down/) 
    {
      ($tmp, $loadavg_down[$downcount]) = split(" ::: ", $_);
      $downcount++;
    }
    
  }
  chomp($mod_lavg_thold);
  $mod_lavg_last_sl = 0;
  close(EFILE);
  
}
sub module_loadavg_unsetup
{
  return(0); # We don't need to unsetup anything.
}
sub parse_loadavg_stage2
{
  my $reported_avg = shift;
  $debug && print "Trying to $reported_avg / $mod_lavg_thold\n";
  my $slevel = int($reported_avg/$mod_lavg_thold);
  my $returnval;
  if ($slevel == $mod_lavg_last_sl) {
    $returnval = "SKIP $slevel";
  } elsif ($slevel > $mod_lavg_last_sl) {
    $returnval = "UP $slevel";
  } elsif ($slevel < $mod_lavg_last_sl) {
    $returnval = "DOWN $slevel";
  }
  $mod_lavg_last_sl = $slevel;
  $debug && print "load average stage 2: $returnval\n"; 
  return "$returnval";
}

sub module_loadavg_output
{
  my $thingy = shift;
  my @rets;
  $debug && print "load average output reports $thingy as \$thingy \n";
  $_ = $thingy;
  if (/^SKIP/) 
  {
    @rets = "NONE", "NONE";
  }
  elsif (/^UP/)
  {
    my ($nothing, $uplev) = split;
    if ($uplev > $#loadavg_up)
    {
      @rets = split(" %%% ", $loadavg_up[$#loadavg_up]);  
    }
    else
    {
      @rets = split(" %%% ", $loadavg_up[$uplev]);
    }
  }
  elsif (/^DOWN/)
  {
    my ($nothing, $downlev) = split;
    if ($downlev > $#loadavg_down)
    {
      @rets = split(" %%% ", $loadavg_down[$#loadavg_up]);  
    }
    else
    {
      @rets = split(" %%% ", $loadavg_down[$downlev]);
    }
  }
  return(@rets);  
}


return 1;
